@@ -54,7 +54,7 @@ void Types_NewObj (PTR (* o), Types__Type t) {
   *o = var;
 }
 
-Types__Type Types_This (Kernel__Module mod, const OOC_CHAR *name) {
+Types__Type Types_This (Kernel__Module mod, const CHAR *name) {
   Types__Type td = (Types__Type)mod->tdescs;
   while (td) {
     if (!strcmp((const char*)name, (const char*)td->name)) {
