@@ -1,6 +1,6 @@
-/*	$Id: __oo2c.h,v 1.21 2000/09/23 19:40:51 ooc-devel Exp $	*/
+/*	$Id: __oo2c.h,v 1.17 1999/10/03 11:51:00 ooc-devel Exp $	*/
 /*  Run-time system for oo2c programs.
-    Copyright (C) 1997-2000  Michael van Acken
+    Copyright (C) 1997-1999  Michael van Acken
 
     This module is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public License
@@ -23,9 +23,7 @@
 
 /* AIX requires this to be the first thing in the file, except for 
    comments and preprocessor directives */
-#ifdef __VISUALC__
-#    include <malloc.h>
-#elif defined(_ALLOCA_H)
+#if defined(_ALLOCA_H)
 /* ignore if alloca.h has already been included */
 #elif __GNUC__
 #  define alloca __builtin_alloca
@@ -90,7 +88,7 @@ extern void NORETURN _array_stack_overflow(_Pos pos) NORETURN2;
 #define _div_by_zero _integer_div_by_zero 
   /* for compability between 1.3.1 and 1.3.2; will be removed later... */
 
-extern void NORETURN _default_exception_handler(void* source, LONGINT number, const OOC_CHAR* message) NORETURN2;
+extern void NORETURN _default_exception_handler(void* source, LONGINT number, const CHAR* message) NORETURN2;
 extern void NORETURN _halt(LONGINT code) NORETURN2;
 
 
@@ -187,7 +185,7 @@ extern char* _end_vs;  /* end of value stack */
 
 #define _string_copy2l(_dest,_src,_max_len) {				\
   LONGCHAR* _d=(LONGCHAR*)_dest;					\
-  const OOC_CHAR* _s=(const OOC_CHAR*)_src;					\
+  const CHAR* _s=(const CHAR*)_src;					\
   LONGCHAR* _max=_d+_max_len-1;						\
   while ((_d != _max) && (*(_d++) = (LONGCHAR)*(_s++)));		\
   if (_d == _max) *_d = 0;						\
@@ -227,8 +225,7 @@ extern int strcmpl(const LONGCHAR *S1, const LONGCHAR *S2);
 #define _P(pos) pos##U*1024+_mid
 extern void _oo2c_init(void);
 extern LONGINT _program_argc;
-extern OOC_CHAR **_program_argv;
+extern CHAR **_program_argv;
 extern INTEGER _program_exit_code;
-#define _not_zero(_x) ((_x)?(_x):1)
 
 #endif /* __oo2c__ */
